@@ -54,7 +54,7 @@ class HeaderToLabelMiddleware(object):
             type=self._REQUEST,
             request_start_time_ms=self._request_start_time,
             method=request.method,
-            url=request.build_absolute_uri()
+            url=Utils.obfuscate_url(request.build_absolute_uri())
         )
         log_entry_info.update(headers)
 
@@ -64,7 +64,7 @@ class HeaderToLabelMiddleware(object):
             request_end_time_ms=Utils.get_time_in_milliseconds(),
             method=request.method,
             body=Utils.obfuscate_body(Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE))),
-            url=request.build_absolute_uri()
+            url=Utils.obfuscate_url(request.build_absolute_uri())
         )
         log_entry_debug.update(headers)
 
@@ -90,7 +90,7 @@ class HeaderToLabelMiddleware(object):
             status_code=response.status_code,
             response=Utils.obfuscate_response(Utils.adjust_string_length(response.content,
                                                 settings.MAX_REQUEST_RESPONSE_SIZE) if response.status_code < 400 else response.content),
-            url=request.build_absolute_uri()
+            url=Utils.obfuscate_url(request.build_absolute_uri())
         )
         log_entry.update(headers)
 
@@ -100,7 +100,7 @@ class HeaderToLabelMiddleware(object):
             request_end_time_ms=Utils.get_time_in_milliseconds(),
             status_code=response.status_code,
             method=request.method,
-            url=request.build_absolute_uri()
+            url=Utils.obfuscate_url(request.build_absolute_uri())
         )
         log_entry_info.update(log_entry_info)
 
@@ -133,7 +133,7 @@ class HeaderToLabelMiddleware(object):
             body=Utils.obfuscate_body(Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE))),
             status_code="500",
             exception=str(exception),
-            url=request.build_absolute_uri(),
+            url=Utils.obfuscate_url(request.build_absolute_uri()),
             stack_trace=traceback.format_exc()
         )
         log_entry.update(headers)
@@ -144,7 +144,7 @@ class HeaderToLabelMiddleware(object):
             request_end_time_ms=Utils.get_time_in_milliseconds(),
             status_code="500",
             method=request.method,
-            url=request.build_absolute_uri()
+            url=Utils.obfuscate_url(request.build_absolute_uri())
         )
         log_entry_info.update(headers)
 
