@@ -80,3 +80,13 @@ class Utils:
                     response = re.sub(pattern, replacement, response)
 
         return response
+
+    @classmethod
+    def obfuscate_url(cls, url):
+        log_label_obfuscate = getattr(settings, LOG_LABEL_OBFUSCATE, dict())
+        if "url" in log_label_obfuscate:
+            for pattern, replacement in log_label_obfuscate["url"].items():
+                if re.search(pattern, url):
+                    response = re.sub(pattern, replacement, response)
+
+        return url
